# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageIntensityPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkIntensityWindowingImageFilterPython
else:
    import _itkIntensityWindowingImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterAPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkImageRegionPython
import itk.itkRGBPixelPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterBPython

def itkIntensityWindowingImageFilterIF2IF2_Superclass_New():
    return itkIntensityWindowingImageFilterIF2IF2_Superclass.New()

class itkIntensityWindowingImageFilterIF2IF2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2IF2):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIF2IF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIF2IF2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIF2IF2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< float,float >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< float,float > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< float,float > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIF2IF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIF2IF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIF2IF2_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterIF2IF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIF2IF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIF2IF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIF2IF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIF2IF2_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_Superclass_swigregister(itkIntensityWindowingImageFilterIF2IF2_Superclass)

def itkIntensityWindowingImageFilterIF2ISS2_Superclass_New():
    return itkIntensityWindowingImageFilterIF2ISS2_Superclass.New()

class itkIntensityWindowingImageFilterIF2ISS2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2ISS2):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIF2ISS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIF2ISS2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIF2ISS2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< float,short >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< float,short > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< float,short > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIF2ISS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIF2ISS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIF2ISS2_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterIF2ISS2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIF2ISS2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIF2ISS2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIF2ISS2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIF2ISS2_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_Superclass_swigregister(itkIntensityWindowingImageFilterIF2ISS2_Superclass)

def itkIntensityWindowingImageFilterIF2IUC2_Superclass_New():
    return itkIntensityWindowingImageFilterIF2IUC2_Superclass.New()

class itkIntensityWindowingImageFilterIF2IUC2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2IUC2):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIF2IUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIF2IUC2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIF2IUC2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< float,unsigned char >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< float,unsigned char > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< float,unsigned char > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIF2IUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIF2IUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIF2IUC2_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterIF2IUC2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIF2IUC2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIF2IUC2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIF2IUC2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIF2IUC2_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_Superclass_swigregister(itkIntensityWindowingImageFilterIF2IUC2_Superclass)

def itkIntensityWindowingImageFilterIF3IF3_Superclass_New():
    return itkIntensityWindowingImageFilterIF3IF3_Superclass.New()

class itkIntensityWindowingImageFilterIF3IF3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3IF3):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIF3IF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIF3IF3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIF3IF3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< float,float >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< float,float > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< float,float > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIF3IF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIF3IF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIF3IF3_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterIF3IF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIF3IF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIF3IF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIF3IF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIF3IF3_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_Superclass_swigregister(itkIntensityWindowingImageFilterIF3IF3_Superclass)

def itkIntensityWindowingImageFilterIF3ISS3_Superclass_New():
    return itkIntensityWindowingImageFilterIF3ISS3_Superclass.New()

class itkIntensityWindowingImageFilterIF3ISS3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3ISS3):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIF3ISS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIF3ISS3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIF3ISS3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< float,short >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< float,short > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< float,short > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIF3ISS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIF3ISS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIF3ISS3_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterIF3ISS3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIF3ISS3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIF3ISS3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIF3ISS3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIF3ISS3_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_Superclass_swigregister(itkIntensityWindowingImageFilterIF3ISS3_Superclass)

def itkIntensityWindowingImageFilterIF3IUC3_Superclass_New():
    return itkIntensityWindowingImageFilterIF3IUC3_Superclass.New()

class itkIntensityWindowingImageFilterIF3IUC3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3IUC3):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIF3IUC3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIF3IUC3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIF3IUC3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< float,unsigned char >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< float,unsigned char > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< float,unsigned char > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIF3IUC3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIF3IUC3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIF3IUC3_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterIF3IUC3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIF3IUC3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIF3IUC3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIF3IUC3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIF3IUC3_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_Superclass_swigregister(itkIntensityWindowingImageFilterIF3IUC3_Superclass)

def itkIntensityWindowingImageFilterISS2IF2_Superclass_New():
    return itkIntensityWindowingImageFilterISS2IF2_Superclass.New()

class itkIntensityWindowingImageFilterISS2IF2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS2IF2):
    r"""Proxy of C++ itkIntensityWindowingImageFilterISS2IF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterISS2IF2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterISS2IF2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< short,float >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< short,float > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< short,float > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterISS2IF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterISS2IF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterISS2IF2_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterISS2IF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterISS2IF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterISS2IF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterISS2IF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterISS2IF2_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_Superclass_swigregister(itkIntensityWindowingImageFilterISS2IF2_Superclass)

def itkIntensityWindowingImageFilterISS2ISS2_Superclass_New():
    return itkIntensityWindowingImageFilterISS2ISS2_Superclass.New()

class itkIntensityWindowingImageFilterISS2ISS2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS2ISS2):
    r"""Proxy of C++ itkIntensityWindowingImageFilterISS2ISS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< short,short >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< short,short > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< short,short > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterISS2ISS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterISS2ISS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterISS2ISS2_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterISS2ISS2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterISS2ISS2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterISS2ISS2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterISS2ISS2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterISS2ISS2_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_Superclass_swigregister(itkIntensityWindowingImageFilterISS2ISS2_Superclass)

def itkIntensityWindowingImageFilterISS2IUC2_Superclass_New():
    return itkIntensityWindowingImageFilterISS2IUC2_Superclass.New()

class itkIntensityWindowingImageFilterISS2IUC2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS2IUC2):
    r"""Proxy of C++ itkIntensityWindowingImageFilterISS2IUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterISS2IUC2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterISS2IUC2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< short,unsigned char >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< short,unsigned char > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< short,unsigned char > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterISS2IUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterISS2IUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterISS2IUC2_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterISS2IUC2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterISS2IUC2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterISS2IUC2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterISS2IUC2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterISS2IUC2_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_Superclass_swigregister(itkIntensityWindowingImageFilterISS2IUC2_Superclass)

def itkIntensityWindowingImageFilterISS3IF3_Superclass_New():
    return itkIntensityWindowingImageFilterISS3IF3_Superclass.New()

class itkIntensityWindowingImageFilterISS3IF3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS3IF3):
    r"""Proxy of C++ itkIntensityWindowingImageFilterISS3IF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterISS3IF3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterISS3IF3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< short,float >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< short,float > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< short,float > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterISS3IF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterISS3IF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterISS3IF3_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterISS3IF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterISS3IF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterISS3IF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterISS3IF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterISS3IF3_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_Superclass_swigregister(itkIntensityWindowingImageFilterISS3IF3_Superclass)

def itkIntensityWindowingImageFilterISS3ISS3_Superclass_New():
    return itkIntensityWindowingImageFilterISS3ISS3_Superclass.New()

class itkIntensityWindowingImageFilterISS3ISS3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS3ISS3):
    r"""Proxy of C++ itkIntensityWindowingImageFilterISS3ISS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< short,short >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< short,short > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< short,short > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterISS3ISS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterISS3ISS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterISS3ISS3_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterISS3ISS3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterISS3ISS3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterISS3ISS3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterISS3ISS3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterISS3ISS3_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_Superclass_swigregister(itkIntensityWindowingImageFilterISS3ISS3_Superclass)

def itkIntensityWindowingImageFilterISS3IUC3_Superclass_New():
    return itkIntensityWindowingImageFilterISS3IUC3_Superclass.New()

class itkIntensityWindowingImageFilterISS3IUC3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS3IUC3):
    r"""Proxy of C++ itkIntensityWindowingImageFilterISS3IUC3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterISS3IUC3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterISS3IUC3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< short,unsigned char >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< short,unsigned char > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< short,unsigned char > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterISS3IUC3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterISS3IUC3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterISS3IUC3_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterISS3IUC3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterISS3IUC3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterISS3IUC3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterISS3IUC3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterISS3IUC3_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_Superclass_swigregister(itkIntensityWindowingImageFilterISS3IUC3_Superclass)

def itkIntensityWindowingImageFilterIUC2IF2_Superclass_New():
    return itkIntensityWindowingImageFilterIUC2IF2_Superclass.New()

class itkIntensityWindowingImageFilterIUC2IF2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC2IF2):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIUC2IF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIUC2IF2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIUC2IF2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< unsigned char,float >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< unsigned char,float > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< unsigned char,float > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIUC2IF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIUC2IF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIUC2IF2_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterIUC2IF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIUC2IF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIUC2IF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIUC2IF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIUC2IF2_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_Superclass_swigregister(itkIntensityWindowingImageFilterIUC2IF2_Superclass)

def itkIntensityWindowingImageFilterIUC2ISS2_Superclass_New():
    return itkIntensityWindowingImageFilterIUC2ISS2_Superclass.New()

class itkIntensityWindowingImageFilterIUC2ISS2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC2ISS2):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIUC2ISS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIUC2ISS2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIUC2ISS2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< unsigned char,short >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< unsigned char,short > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< unsigned char,short > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIUC2ISS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIUC2ISS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIUC2ISS2_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterIUC2ISS2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIUC2ISS2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIUC2ISS2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIUC2ISS2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIUC2ISS2_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_Superclass_swigregister(itkIntensityWindowingImageFilterIUC2ISS2_Superclass)

def itkIntensityWindowingImageFilterIUC2IUC2_Superclass_New():
    return itkIntensityWindowingImageFilterIUC2IUC2_Superclass.New()

class itkIntensityWindowingImageFilterIUC2IUC2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC2IUC2):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIUC2IUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIUC2IUC2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIUC2IUC2_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< unsigned char,unsigned char >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< unsigned char,unsigned char > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< unsigned char,unsigned char > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIUC2IUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIUC2IUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIUC2IUC2_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterIUC2IUC2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIUC2IUC2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIUC2IUC2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIUC2IUC2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIUC2IUC2_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_Superclass_swigregister(itkIntensityWindowingImageFilterIUC2IUC2_Superclass)

def itkIntensityWindowingImageFilterIUC3IF3_Superclass_New():
    return itkIntensityWindowingImageFilterIUC3IF3_Superclass.New()

class itkIntensityWindowingImageFilterIUC3IF3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC3IF3):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIUC3IF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIUC3IF3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIUC3IF3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< unsigned char,float >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< unsigned char,float > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< unsigned char,float > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIUC3IF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIUC3IF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIUC3IF3_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterIUC3IF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIUC3IF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIUC3IF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIUC3IF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIUC3IF3_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_Superclass_swigregister(itkIntensityWindowingImageFilterIUC3IF3_Superclass)

def itkIntensityWindowingImageFilterIUC3ISS3_Superclass_New():
    return itkIntensityWindowingImageFilterIUC3ISS3_Superclass.New()

class itkIntensityWindowingImageFilterIUC3ISS3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC3ISS3):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIUC3ISS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIUC3ISS3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIUC3ISS3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< unsigned char,short >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< unsigned char,short > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< unsigned char,short > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIUC3ISS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIUC3ISS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIUC3ISS3_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterIUC3ISS3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIUC3ISS3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIUC3ISS3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIUC3ISS3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIUC3ISS3_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_Superclass_swigregister(itkIntensityWindowingImageFilterIUC3ISS3_Superclass)

def itkIntensityWindowingImageFilterIUC3IUC3_Superclass_New():
    return itkIntensityWindowingImageFilterIUC3IUC3_Superclass.New()

class itkIntensityWindowingImageFilterIUC3IUC3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC3IUC3):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIUC3IUC3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIUC3IUC3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIUC3IUC3_Superclass_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< unsigned char,unsigned char >
        GetFunctor(self) -> itk::Functor::IntensityWindowingTransform< unsigned char,unsigned char > const &
        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::IntensityWindowingTransform< unsigned char,unsigned char > const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIUC3IUC3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIUC3IUC3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIUC3IUC3_Superclass

        Create a new object of the class itkIntensityWindowingImageFilterIUC3IUC3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIUC3IUC3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIUC3IUC3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIUC3IUC3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIUC3IUC3_Superclass in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_Superclass_swigregister(itkIntensityWindowingImageFilterIUC3IUC3_Superclass)

def itkIntensityWindowingImageFilterIF2IF2_New():
    return itkIntensityWindowingImageFilterIF2IF2.New()

class itkIntensityWindowingImageFilterIF2IF2(itkIntensityWindowingImageFilterIF2IF2_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIF2IF2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIF2IF2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: float const &
        level: float const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> float"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> float"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIF2IF2

        Create a new object of the class itkIntensityWindowingImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIF2IF2 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IF2_swigregister(itkIntensityWindowingImageFilterIF2IF2)

def itkIntensityWindowingImageFilterIF2ISS2_New():
    return itkIntensityWindowingImageFilterIF2ISS2.New()

class itkIntensityWindowingImageFilterIF2ISS2(itkIntensityWindowingImageFilterIF2ISS2_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIF2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIF2ISS2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIF2ISS2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: float const &
        level: float const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> float"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> float"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIF2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIF2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIF2ISS2

        Create a new object of the class itkIntensityWindowingImageFilterIF2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIF2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIF2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIF2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIF2ISS2 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2ISS2_swigregister(itkIntensityWindowingImageFilterIF2ISS2)

def itkIntensityWindowingImageFilterIF2IUC2_New():
    return itkIntensityWindowingImageFilterIF2IUC2.New()

class itkIntensityWindowingImageFilterIF2IUC2(itkIntensityWindowingImageFilterIF2IUC2_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIF2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIF2IUC2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIF2IUC2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: float const &
        level: float const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> float"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> float"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIF2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIF2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIF2IUC2

        Create a new object of the class itkIntensityWindowingImageFilterIF2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIF2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIF2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIF2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIF2IUC2 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF2IUC2_swigregister(itkIntensityWindowingImageFilterIF2IUC2)

def itkIntensityWindowingImageFilterIF3IF3_New():
    return itkIntensityWindowingImageFilterIF3IF3.New()

class itkIntensityWindowingImageFilterIF3IF3(itkIntensityWindowingImageFilterIF3IF3_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIF3IF3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIF3IF3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: float const &
        level: float const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> float"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> float"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIF3IF3

        Create a new object of the class itkIntensityWindowingImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIF3IF3 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IF3_swigregister(itkIntensityWindowingImageFilterIF3IF3)

def itkIntensityWindowingImageFilterIF3ISS3_New():
    return itkIntensityWindowingImageFilterIF3ISS3.New()

class itkIntensityWindowingImageFilterIF3ISS3(itkIntensityWindowingImageFilterIF3ISS3_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIF3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIF3ISS3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIF3ISS3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: float const &
        level: float const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> float"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> float"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIF3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIF3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIF3ISS3

        Create a new object of the class itkIntensityWindowingImageFilterIF3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIF3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIF3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIF3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIF3ISS3 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3ISS3_swigregister(itkIntensityWindowingImageFilterIF3ISS3)

def itkIntensityWindowingImageFilterIF3IUC3_New():
    return itkIntensityWindowingImageFilterIF3IUC3.New()

class itkIntensityWindowingImageFilterIF3IUC3(itkIntensityWindowingImageFilterIF3IUC3_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIF3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIF3IUC3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIF3IUC3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: float const &
        level: float const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> float"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> float"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIF3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIF3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIF3IUC3

        Create a new object of the class itkIntensityWindowingImageFilterIF3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIF3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIF3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIF3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIF3IUC3 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIF3IUC3_swigregister(itkIntensityWindowingImageFilterIF3IUC3)

def itkIntensityWindowingImageFilterISS2IF2_New():
    return itkIntensityWindowingImageFilterISS2IF2.New()

class itkIntensityWindowingImageFilterISS2IF2(itkIntensityWindowingImageFilterISS2IF2_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterISS2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterISS2IF2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterISS2IF2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: short const &
        level: short const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> short"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> short"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterISS2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterISS2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterISS2IF2

        Create a new object of the class itkIntensityWindowingImageFilterISS2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterISS2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterISS2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterISS2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterISS2IF2 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IF2_swigregister(itkIntensityWindowingImageFilterISS2IF2)

def itkIntensityWindowingImageFilterISS2ISS2_New():
    return itkIntensityWindowingImageFilterISS2ISS2.New()

class itkIntensityWindowingImageFilterISS2ISS2(itkIntensityWindowingImageFilterISS2ISS2_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterISS2ISS2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterISS2ISS2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: short const &
        level: short const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> short"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> short"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterISS2ISS2

        Create a new object of the class itkIntensityWindowingImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterISS2ISS2 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2ISS2_swigregister(itkIntensityWindowingImageFilterISS2ISS2)

def itkIntensityWindowingImageFilterISS2IUC2_New():
    return itkIntensityWindowingImageFilterISS2IUC2.New()

class itkIntensityWindowingImageFilterISS2IUC2(itkIntensityWindowingImageFilterISS2IUC2_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterISS2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterISS2IUC2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterISS2IUC2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: short const &
        level: short const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> short"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> short"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterISS2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterISS2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterISS2IUC2

        Create a new object of the class itkIntensityWindowingImageFilterISS2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterISS2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterISS2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterISS2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterISS2IUC2 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS2IUC2_swigregister(itkIntensityWindowingImageFilterISS2IUC2)

def itkIntensityWindowingImageFilterISS3IF3_New():
    return itkIntensityWindowingImageFilterISS3IF3.New()

class itkIntensityWindowingImageFilterISS3IF3(itkIntensityWindowingImageFilterISS3IF3_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterISS3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterISS3IF3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterISS3IF3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: short const &
        level: short const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> short"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> short"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterISS3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterISS3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterISS3IF3

        Create a new object of the class itkIntensityWindowingImageFilterISS3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterISS3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterISS3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterISS3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterISS3IF3 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IF3_swigregister(itkIntensityWindowingImageFilterISS3IF3)

def itkIntensityWindowingImageFilterISS3ISS3_New():
    return itkIntensityWindowingImageFilterISS3ISS3.New()

class itkIntensityWindowingImageFilterISS3ISS3(itkIntensityWindowingImageFilterISS3ISS3_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterISS3ISS3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterISS3ISS3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: short const &
        level: short const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> short"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> short"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterISS3ISS3

        Create a new object of the class itkIntensityWindowingImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterISS3ISS3 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3ISS3_swigregister(itkIntensityWindowingImageFilterISS3ISS3)

def itkIntensityWindowingImageFilterISS3IUC3_New():
    return itkIntensityWindowingImageFilterISS3IUC3.New()

class itkIntensityWindowingImageFilterISS3IUC3(itkIntensityWindowingImageFilterISS3IUC3_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterISS3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterISS3IUC3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterISS3IUC3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: short const &
        level: short const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> short"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> short"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterISS3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterISS3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterISS3IUC3

        Create a new object of the class itkIntensityWindowingImageFilterISS3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterISS3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterISS3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterISS3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterISS3IUC3 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterISS3IUC3_swigregister(itkIntensityWindowingImageFilterISS3IUC3)

def itkIntensityWindowingImageFilterIUC2IF2_New():
    return itkIntensityWindowingImageFilterIUC2IF2.New()

class itkIntensityWindowingImageFilterIUC2IF2(itkIntensityWindowingImageFilterIUC2IF2_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIUC2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIUC2IF2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIUC2IF2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: unsigned char const &
        level: unsigned char const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> unsigned char"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> unsigned char"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIUC2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIUC2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIUC2IF2

        Create a new object of the class itkIntensityWindowingImageFilterIUC2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIUC2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIUC2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIUC2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIUC2IF2 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IF2_swigregister(itkIntensityWindowingImageFilterIUC2IF2)

def itkIntensityWindowingImageFilterIUC2ISS2_New():
    return itkIntensityWindowingImageFilterIUC2ISS2.New()

class itkIntensityWindowingImageFilterIUC2ISS2(itkIntensityWindowingImageFilterIUC2ISS2_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIUC2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIUC2ISS2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIUC2ISS2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: unsigned char const &
        level: unsigned char const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> unsigned char"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> unsigned char"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIUC2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIUC2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIUC2ISS2

        Create a new object of the class itkIntensityWindowingImageFilterIUC2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIUC2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIUC2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIUC2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIUC2ISS2 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2ISS2_swigregister(itkIntensityWindowingImageFilterIUC2ISS2)

def itkIntensityWindowingImageFilterIUC2IUC2_New():
    return itkIntensityWindowingImageFilterIUC2IUC2.New()

class itkIntensityWindowingImageFilterIUC2IUC2(itkIntensityWindowingImageFilterIUC2IUC2_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIUC2IUC2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIUC2IUC2_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: unsigned char const &
        level: unsigned char const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> unsigned char"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> unsigned char"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIUC2IUC2

        Create a new object of the class itkIntensityWindowingImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIUC2IUC2 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC2IUC2_swigregister(itkIntensityWindowingImageFilterIUC2IUC2)

def itkIntensityWindowingImageFilterIUC3IF3_New():
    return itkIntensityWindowingImageFilterIUC3IF3.New()

class itkIntensityWindowingImageFilterIUC3IF3(itkIntensityWindowingImageFilterIUC3IF3_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIUC3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIUC3IF3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIUC3IF3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> float const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: unsigned char const &
        level: unsigned char const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> unsigned char"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> unsigned char"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIUC3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIUC3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIUC3IF3

        Create a new object of the class itkIntensityWindowingImageFilterIUC3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIUC3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIUC3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIUC3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIUC3IF3 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IF3_swigregister(itkIntensityWindowingImageFilterIUC3IF3)

def itkIntensityWindowingImageFilterIUC3ISS3_New():
    return itkIntensityWindowingImageFilterIUC3ISS3.New()

class itkIntensityWindowingImageFilterIUC3ISS3(itkIntensityWindowingImageFilterIUC3ISS3_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIUC3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIUC3ISS3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIUC3ISS3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> short const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: unsigned char const &
        level: unsigned char const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> unsigned char"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> unsigned char"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIUC3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIUC3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIUC3ISS3

        Create a new object of the class itkIntensityWindowingImageFilterIUC3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIUC3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIUC3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIUC3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIUC3ISS3 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3ISS3_swigregister(itkIntensityWindowingImageFilterIUC3ISS3)

def itkIntensityWindowingImageFilterIUC3IUC3_New():
    return itkIntensityWindowingImageFilterIUC3IUC3.New()

class itkIntensityWindowingImageFilterIUC3IUC3(itkIntensityWindowingImageFilterIUC3IUC3_Superclass):
    r"""Proxy of C++ itkIntensityWindowingImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIntensityWindowingImageFilterIUC3IUC3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIntensityWindowingImageFilterIUC3IUC3_Pointer"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_Clone(self)

    def SetOutputMinimum(self, _arg):
        r"""
        SetOutputMinimum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_SetOutputMinimum(self, _arg)

    def SetOutputMaximum(self, _arg):
        r"""
        SetOutputMaximum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_SetOutputMaximum(self, _arg)

    def GetOutputMinimum(self):
        r"""GetOutputMinimum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_GetOutputMinimum(self)

    def GetOutputMaximum(self):
        r"""GetOutputMaximum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_GetOutputMaximum(self)

    def SetWindowMinimum(self, _arg):
        r"""
        SetWindowMinimum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_SetWindowMinimum(self, _arg)

    def SetWindowMaximum(self, _arg):
        r"""
        SetWindowMaximum(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_SetWindowMaximum(self, _arg)

    def GetWindowMinimum(self):
        r"""GetWindowMinimum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_GetWindowMinimum(self)

    def GetWindowMaximum(self):
        r"""GetWindowMaximum(self) -> unsigned char const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_GetWindowMaximum(self)

    def SetWindowLevel(self, window, level):
        r"""
        SetWindowLevel(self, window, level)

        Parameters
        ----------
        window: unsigned char const &
        level: unsigned char const &

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_SetWindowLevel(self, window, level)

    def GetWindow(self):
        r"""GetWindow(self) -> unsigned char"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_GetWindow(self)

    def GetLevel(self):
        r"""GetLevel(self) -> unsigned char"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_GetLevel(self)

    def GetScale(self):
        r"""GetScale(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_GetScale(self)

    def GetShift(self):
        r"""GetShift(self) -> double const &"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_GetShift(self)

    def BeforeThreadedGenerateData(self):
        r"""BeforeThreadedGenerateData(self)"""
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_BeforeThreadedGenerateData(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_PrintSelf(self, os, indent)
    InputHasNumericTraitsCheck = _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIntensityWindowingImageFilterPython.delete_itkIntensityWindowingImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIntensityWindowingImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIntensityWindowingImageFilterIUC3IUC3

        Create a new object of the class itkIntensityWindowingImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIntensityWindowingImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIntensityWindowingImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIntensityWindowingImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIntensityWindowingImageFilterIUC3IUC3 in _itkIntensityWindowingImageFilterPython:
_itkIntensityWindowingImageFilterPython.itkIntensityWindowingImageFilterIUC3IUC3_swigregister(itkIntensityWindowingImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def intensity_windowing_image_filter(*args: itkt.ImageLike,  output_minimum: float=..., output_maximum: float=..., window_minimum: float=..., window_maximum: float=..., window_level: float=..., functor=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for IntensityWindowingImageFilter"""
    import itk

    kwarg_typehints = { 'output_minimum':output_minimum,'output_maximum':output_maximum,'window_minimum':window_minimum,'window_maximum':window_maximum,'window_level':window_level,'functor':functor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.IntensityWindowingImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def intensity_windowing_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageIntensity.IntensityWindowingImageFilter
    intensity_windowing_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    intensity_windowing_image_filter.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def unary_functor_image_filter(*args: itkt.ImageLike,  functor=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for UnaryFunctorImageFilter"""
    import itk

    kwarg_typehints = { 'functor':functor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.UnaryFunctorImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def unary_functor_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageIntensity.UnaryFunctorImageFilter
    unary_functor_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    unary_functor_image_filter.__doc__ = filter_object.__doc__



